# mod_negotiation.pl
# Defines editors content negotiation directives

sub mod_negotiation_directives
{
$rv = [ [ 'CacheNegotiatedDocs', 0, 6, 'global' ],
        [ 'LanguagePriority', 0, 6, 'virtual directory htaccess' ] ];
return &make_directives($rv, $_[0], "mod_negotiation");
}

sub mod_negotiation_handlers
{
return ("type-map");
}

sub edit_CacheNegotiatedDocs
{
local($v); $v = $_[0] ? "1" : "0";
return (1, "$text{'mod_negotiation_cache'}",
        &choice_input($v, "CacheNegotiatedDocs", "0",
        "$text{'yes'},1", "$text{'no'},0"));
}
sub save_CacheNegotiatedDocs
{
return $in{'CacheNegotiatedDocs'} ? ( [ "" ] ) : ( [ ] );
}

sub edit_LanguagePriority
{
return (1, "$text{'mod_negotiation_pri'}",
        &opt_input($_[0]->{'value'}, "LanguagePriority", "$text{'mod_negotiation_def'}", 15));
}
sub save_LanguagePriority
{
return &parse_opt("LanguagePriority", '\S', "$text{'mod_negotiation_epri'}");
}

1;

